@@ -164,8 +164,7 @@ xfpm_backlight_show_notification (XfpmBacklight *backlight, gfloat value)
 							   "",
 							   "xfpm-brightness-lcd",
 							   0,
-							   XFPM_NOTIFY_NORMAL,
-							   NULL);
+							   XFPM_NOTIFY_NORMAL);
     }
 
     /* generate a human-readable summary for the notification */
